﻿/// <reference path="interface.js" />
/// <reference name "MicrosoftAjax.js" assembly="System.Web.Extensions" />

Type.registerNamespace('Core.Web');

Core.Web.ImageLoader = function(imageContainerID, imageClass, preloaderUrl) {  

  this.imageContainer = $get(imageContainerID);  
  
  this.imageClass = imageClass;
  
  this.preloaderUrl = preloaderUrl;
  
  this.preloaderTitle = 'Loading...';
  
  this.currentImage = null;
  
  this.image = null;
  
  this.preloader = null;
  
  this.init();  
}

Core.Web.ImageLoader.registerClass('Core.Web.ImageLoader');

Core.Web.ImageLoader.prototype = {

  init : function() {
    this.preloader = new Image();
    this.preloader.alt = this.preloaderTitle;
    this.preloader.src = this.preloaderUrl;    
    this.preloader.className = this.imageClass;    
  },

  loadImage : function(imageUrl, imageTitle) {
    this.insertImage(this.preloader);
    this.image = new Image();
    this.image.alt = imageTitle;
    this.image.className = this.imageClass;
    $addHandler(this.image, 'load', Function.createDelegate(this, this.onImageLoadHandler));
    this.image.src = imageUrl;
  },

  onImageLoadHandler : function(event) {
    this.insertImage(this.image);
  },

  insertImage : function(image) {
    this.removeCurrentImage();
    this.resizeImage(image);
    this.currentImage = image;
    this.imageContainer.appendChild(image);
  },

  removeCurrentImage : function() {
    if (this.currentImage) {
      this.removeImage(this.currentImage);
      this.currentImage = null;
    }
  },
  
  removeImage : function(image) {
    if (this.imageContainer && image) {
      if (image) {
        this.imageContainer.removeChild(image);
      }
    }
  },

  resizeImage : function(image) {
    containerWidth = this.imageContainer.clientWidth - 40;
    containerHeight = this.imageContainer.clientHeight - 20;
    containerRatio = containerWidth / containerHeight
    imageWidth = this.getImageWidth(image);
    imageHeight = this.getImageHeight(image);
    imageRatio = imageWidth / imageHeight  
    if (imageRatio > containerRatio) {
      if (imageWidth > containerWidth) {
        imageWidth = containerWidth;
      }
      imageHeight = imageWidth / imageRatio;
      this.setImageSize(image, imageWidth, imageHeight);
    }
    else {
      if (imageHeight > containerHeight) {
        imageHeight = containerHeight;
      }    
      imageWidth = imageHeight * imageRatio;
      this.setImageSize(image, imageWidth, imageHeight);
      
    }
    image.style.left = (containerWidth - imageWidth) / 2 + 13 + 'px';  
    image.style.top = (containerHeight - imageHeight) / 2 + 5 + 'px';
  },

  getImageWidth : function(image) {
    if (image.naturalWidth) {
      return image.naturalWidth;
    }
    if (image.width) {
      return image.width;
    }    
    return 0;
  },
  
  getImageHeight : function(image) {
    if (image.naturalHeight) {
      return image.naturalHeight;
    }
    if (image.height) {
      return image.height;
    }    
    return 0;
  },

  setImageSize : function(image, width, height) {
    if (image) {
      image.style.width = width + 'px';
      image.style.height = height + 'px';
    }  
  }
}